@@ -1,27 +1,13 @@
 /*
-    Copyright 2016 David Edmundson <davidedmundson@kde.org>
+    SPDX-FileCopyrightText: 2016 David Edmundson <davidedmundson@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-
 #include "modulemanager.h"
-#include "module.h"
 #include "../config.h"
+#include "module.h"
+#include "server.h"
 
 #if USE_GSETTINGS
 #include "gsettingsitem.h"
@@ -38,7 +24,6 @@
 
 namespace QPulseAudio
 {
-
 #if USE_GCONF || USE_GSETTINGS
 
 #if USE_GSETTINGS
@@ -50,16 +35,20 @@ class ConfigModule : public GConfItem
 public:
     ConfigModule(const QString &configName, const QString &moduleName, QObject *parent);
     bool isEnabled() const;
-    void setEnabled(bool enabled, const QVariant &args=QVariant());
+    void setEnabled(bool enabled, const QVariant &args = QVariant());
+
 private:
     QString m_moduleName;
 };
 
-ConfigModule::ConfigModule(const QString &configName, const QString &moduleName, QObject *parent) :
+ConfigModule::ConfigModule(const QString &configName, const QString &moduleName, QObject *parent)
+    :
 #if USE_GSETTINGS
-    GSettingsItem(QStringLiteral(PA_SETTINGS_PATH_MODULES"/") + configName + QStringLiteral("/"), parent),
+    GSettingsItem(QStringLiteral(PA_SETTINGS_PATH_MODULES "/") + configName + QStringLiteral("/"), parent)
+    ,
 #elif USE_GCONF
-    GConfItem(QStringLiteral(PA_SETTINGS_PATH_MODULES"/") + configName, parent),
+    GConfItem(QStringLiteral(PA_SETTINGS_PATH_MODULES "/") + configName, parent)
+    ,
 #endif
     m_moduleName(moduleName)
 {
@@ -86,8 +75,8 @@ void ConfigModule::setEnabled(bool enabled, const QVariant &args)
 
 #endif
 
-ModuleManager::ModuleManager(QObject *parent) :
-    QObject(parent)
+ModuleManager::ModuleManager(QObject *parent)
+    : QObject(parent)
 {
 #if USE_GCONF || USE_GSETTINGS
     m_combineSinks = new ConfigModule(QStringLiteral("combine"), QStringLiteral("module-combine"), this);
@@ -103,17 +92,22 @@ ModuleManager::ModuleManager(QObject *parent) :
     updateModulesTimer->setInterval(500);
     updateModulesTimer->setSingleShot(true);
     connect(updateModulesTimer, &QTimer::timeout, this, &ModuleManager::updateLoadedModules);
-    connect(&Context::instance()->modules(), &MapBaseQObject::added, updateModulesTimer, static_cast<void(QTimer::*)(void)>(&QTimer::start));
-    connect(&Context::instance()->modules(), &MapBaseQObject::removed, updateModulesTimer, static_cast<void(QTimer::*)(void)>(&QTimer::start));
+    connect(&Context::instance()->modules(), &MapBaseQObject::added, updateModulesTimer, static_cast<void (QTimer::*)(void)>(&QTimer::start));
+    connect(&Context::instance()->modules(), &MapBaseQObject::removed, updateModulesTimer, static_cast<void (QTimer::*)(void)>(&QTimer::start));
     updateLoadedModules();
 }
 
-ModuleManager::~ModuleManager()
-{
-};
+ModuleManager::~ModuleManager(){};
 
 bool ModuleManager::settingsSupported() const
 {
+    // PipeWire does not (yet) have support for module-switch-on-connect and module-combine-sink
+    // Also switching streams is the default there
+    // TODO Check whether there is a PipeWire-specific way to do these
+    if (Context::instance()->server()->isPipeWire()) {
+        return false;
+    }
+
 #if USE_GCONF || USE_GSETTINGS
     return true;
 #else
@@ -142,12 +136,12 @@ void ModuleManager::setCombineSinks(bool combineSinks)
 bool ModuleManager::switchOnConnect() const
 {
 #if USE_GCONF || USE_GSETTINGS
-    //switch on connect and device-manager do the same task. Only one should be enabled
+    // switch on connect and device-manager do the same task. Only one should be enabled
 
-    //Note on the first run m_deviceManager will appear to be disabled even though it's actually running
-    //because there is no gconf entry, however m_switchOnConnect will only exist if set by Plasma PA
-    //hence only check this entry
-    return m_switchOnConnect->isEnabled() ;
+    // Note on the first run m_deviceManager will appear to be disabled even though it's actually running
+    // because there is no gconf entry, however m_switchOnConnect will only exist if set by Plasma PA
+    // hence only check this entry
+    return m_switchOnConnect->isEnabled();
 #else
     return false;
 #endif
